progress property
Playback progress from 0.0 (start) to 1.0 (end). Bars up to this fraction are drawn in the played colour.
Implementation
final double progress;
Playback progress from 0.0 (start) to 1.0 (end). Bars up to this fraction are drawn in the played colour.
final double progress;